.. currentmodule:: pandas.stats.api

.. _stats:

*****************
Statistical tools
*****************

Least-squares entry-point
-------------------------

.. autosummary::
   :toctree: generated/

   ols

Class reference
---------------

.. currentmodule:: pandas.stats.ols

.. autosummary::
   :toctree: generated/

   OLS
   MovingOLS

.. currentmodule:: pandas.stats.plm

.. autosummary::
   :toctree: generated/

   PanelOLS
   MovingPanelOLS

